/// <reference types="node" />
import { BrowserController, BrowserRequestHandler } from './BrowserController';
export declare class PlaywrightController implements BrowserController {
    private readonly page;
    private readonly onRequest;
    constructor(page: PlaywrightPage, onRequest: BrowserRequestHandler);
    startInterception(): Promise<void>;
    stopInterception(): Promise<void>;
    private requestHandler;
    private toBrowserRequest;
    private respond;
    private skip;
    /**
     * Obtain request origin url from originating frame url
     */
    private getRequestOrigin;
}
/**
 * Mirror of playwright's Page interface
 */
export interface PlaywrightPage {
    route(url: string, handler: (route: PlaywrightRoute, request: PlaywrightRequest) => void): Promise<void>;
    unroute(url: string, handler: (route: PlaywrightRoute, request: PlaywrightRequest) => void): Promise<void>;
}
/**
 * Mirror of playwright's Route interface
 */
interface PlaywrightRoute {
    fulfill(response: PlaywrightRouteFulfillResponse): Promise<void>;
    request(): PlaywrightRequest;
    continue(): Promise<void>;
}
/**
 * Mirror of playwright's Response interface
 */
interface PlaywrightRouteFulfillResponse {
    status?: number;
    headers?: {
        [key: string]: string;
    };
    contentType?: string;
    body?: string | Buffer;
    path?: string;
}
/**
 * Mirror of playwright's Request interface
 */
interface PlaywrightRequest {
    frame(): {
        url(): string;
    };
    headers(): {
        [key: string]: string;
    };
    method(): string;
    postData(): null | string;
    resourceType(): string;
    url(): string;
}
export {};
//# sourceMappingURL=PlaywrightController.d.ts.map