"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const url_1 = require("url");
class PlaywrightController {
    constructor(page, onRequest) {
        this.page = page;
        this.onRequest = onRequest;
        this.requestHandler = (route) => {
            this.onRequest(this.toBrowserRequest(route.request()), (data) => this.respond(route, data), () => this.skip(route));
        };
    }
    async startInterception() {
        await this.page.route('**/*', this.requestHandler);
    }
    async stopInterception() {
        await this.page.unroute('**/*', this.requestHandler);
    }
    toBrowserRequest(request) {
        // TODO find a better alternative for url.parse
        const { pathname, query, protocol, host } = url_1.parse(request.url(), true);
        return {
            type: request.resourceType(),
            url: request.url(),
            body: utils_1.tryJsonParse(request.postData()),
            method: request.method(),
            headers: request.headers() || {},
            path: pathname !== null && pathname !== void 0 ? pathname : '',
            hostname: `${protocol}//${host}`,
            query: query,
            sourceOrigin: this.getRequestOrigin(request),
        };
    }
    async respond(route, response) {
        var _a;
        await route.fulfill({
            headers: response.headers || {},
            status: response.status,
            body: response.body ? response.body : '',
            contentType: (_a = response.headers) === null || _a === void 0 ? void 0 : _a['content-type'],
        });
    }
    async skip(route) {
        await route.continue();
    }
    /**
     * Obtain request origin url from originating frame url
     */
    getRequestOrigin(request) {
        return utils_1.getOrigin(request.frame().url());
    }
}
exports.PlaywrightController = PlaywrightController;
//# sourceMappingURL=PlaywrightController.js.map