/// <reference types="node" />
import { BrowserController, BrowserRequestHandler } from './BrowserController';
export declare class PuppeteerController implements BrowserController {
    private readonly page;
    private readonly onRequest;
    constructor(page: PuppeteerPage, onRequest: BrowserRequestHandler);
    startInterception(): Promise<void>;
    stopInterception(): Promise<void>;
    private requestHandler;
    private toBrowserRequest;
    /**
     * Obtain request origin url from originating frame url
     */
    private getRequestOrigin;
}
/**
 * Mirror of puppeteer Page interface
 */
export interface PuppeteerPage {
    setRequestInterception(enabled: boolean): Promise<void>;
    on(eventName: 'request', handler: (e: PuppeteerRequest) => void): any;
    off(eventName: 'request', handler: (e: PuppeteerRequest) => void): any;
}
/**
 * Mirror of puppeteer Request interface
 */
export interface PuppeteerRequest {
    continue(): Promise<void>;
    frame(): {
        url(): string;
    } | null;
    headers(): Record<string, string>;
    method(): string;
    postData(): string | undefined;
    resourceType(): 'document' | 'stylesheet' | 'image' | 'media' | 'font' | 'script' | 'texttrack' | 'xhr' | 'fetch' | 'eventsource' | 'websocket' | 'manifest' | 'other';
    respond(response: PuppeteerRespondOptions): Promise<void>;
    url(): string;
}
/**
 * Mirror of puppeteer Response interface
 */
interface PuppeteerRespondOptions {
    status?: number;
    headers?: Record<string, string>;
    contentType?: string;
    body?: Buffer | string;
}
export {};
//# sourceMappingURL=PuppeteerController.d.ts.map